@@ -534,7 +534,9 @@ typedef enum sox_encoding_t {
   SOX_ENCODING_DWVW      , /**< Delta Width Variable Word */
   SOX_ENCODING_DWVWN     , /**< Delta Width Variable Word N-bit */
   SOX_ENCODING_GSM       , /**< GSM 6.10 33byte frame lossy compression */
-  SOX_ENCODING_MP3       , /**< MP3 compression */
+  SOX_ENCODING_MP1       , /**< MPEG 1 Layer 1 compression */
+  SOX_ENCODING_MP2       , /**< MPEG 1 Layer 2 compression */
+  SOX_ENCODING_MP3       , /**< MPEG 1 Layer 3 compression */
   SOX_ENCODING_VORBIS    , /**< Vorbis compression */
   SOX_ENCODING_AMR_WB    , /**< AMR-WB compression */
   SOX_ENCODING_AMR_NB    , /**< AMR-NB compression */
@@ -611,7 +613,7 @@ The API version of the sox_ng.h file. It is not meant to follow the version
 number of SoX but it has historically. Please do not count on
 SOX_LIB_VERSION_CODE staying in sync with the libSoX version.
 */
-#define SOX_LIB_VERSION_CODE   SOX_LIB_VERSION(14, 6, 1)
+#define SOX_LIB_VERSION_CODE   SOX_LIB_VERSION(14, 7, 0)
 
 /**
 Client API:
@@ -1025,7 +1027,7 @@ if clipping occurs.
 #define SOX_FILE_STEREO  0x0200 /**< Client API: Do channel restrictions allow stereo? */
 #define SOX_FILE_QUAD    0x0400 /**< Client API: Do channel restrictions allow quad? */
 
-#define SOX_FILE_CHANS   (SOX_FILE_MONO | SOX_FILE_STEREO | SOX_FILE_QUAD) /**< Client API: No channel restrictions */
+#define SOX_FILE_CHANS   (SOX_FILE_MONO | SOX_FILE_STEREO | SOX_FILE_QUAD) /**< Client API: Mask to interrogate channels restrictions. If a sox_format_handler_t.flags & SOX_FILE_CHANS is 0 there are no restrictions. */
 #define SOX_FILE_LIT_END (SOX_FILE_ENDIAN | 0)                             /**< Client API: File is little-endian */
 #define SOX_FILE_BIG_END (SOX_FILE_ENDIAN | SOX_FILE_ENDBIG)               /**< Client API: File is big-endian */
 
@@ -1282,6 +1284,7 @@ function.
 */
 typedef struct sox_globals {
 /* public: */
+  char *       myname;  /**< argv[0] */
   unsigned     verbosity; /**< messages are only written if globals.verbosity >= message.level */
   sox_output_message_handler_t output_message_handler; /**< client-specified message output callback */
   sox_bool     repeatable; /**< true to use pre-determined timestamps and PRNG seed */
@@ -1598,7 +1601,7 @@ Client API:
 Returns version number string of libSoX, for example, "14.4.0".
 @returns The version number string of libSoX, for example, "14.4.0".
 */
-LSX_RETURN_VALID_Z LSX_RETURN_PURE
+LSX_RETURN_VALID_Z
 char const *
 LSX_API
 sox_version(void);
@@ -1608,7 +1611,7 @@ Client API:
 Returns information about this build of libsox.
 @returns Pointer to a version information structure.
 */
-LSX_RETURN_VALID
+LSX_RETURN_VALID LSX_RETURN_PURE
 sox_version_info_t const *
 LSX_API
 sox_version_info(void);
@@ -2464,7 +2467,6 @@ lsx_strcasecmp(
     LSX_PARAM_IN_Z char const * s2  /**< Second string. */
     );
 
-
 /**
 Plugins API:
 Like strncmp, except that the characters are compared without regard to case.
@@ -2479,6 +2481,19 @@ lsx_strncasecmp(
     size_t n /**< Maximum number of characters to examine. */
     );
 
+/**
+Plugins API:
+Like strtod, but checking for broken strtod() at runtime and
+disallowing NaN.
+Note: *not* LSX_RETURN_PURE
+*/
+double
+LSX_API
+lsx_strtod(
+    LSX_PARAM_IN_Z char const * nptr, /**< String to convert */
+    LSX_PARAM_OUT_OPT char ** endptr  /**< If not NULL, set to the address of the first char not used in conversion */
+    );
+
 /**
 Plugins API:
 Is option argument unsupported, required, or optional.
@@ -2503,7 +2518,7 @@ typedef enum lsx_getopt_flags_t {
 Plugins API:
 lsx_getopt long option descriptor.
 */
-typedef struct lsx_option_t {
+typedef struct lsx_option {
     char const *     name;    /**< Name of the long option. */
     lsx_option_arg_t has_arg; /**< Whether the long option supports an argument and, if so, whether the argument is required or optional. */
     int *            flag;    /**< Flag to set if argument is present. */
@@ -2514,7 +2529,7 @@ typedef struct lsx_option_t {
 Plugins API:
 lsx_getopt session information (initialization data and state).
 */
-typedef struct lsx_getopt_t {
+typedef struct lsx_getopt {
     int                  argc;     /**< IN    argc:      Number of arguments in argv */
     char * const *       argv;     /**< IN    argv:      Array of arguments */
     char const *         shortopts;/**< IN    shortopts: Short option characters */
